@@ -9,7 +9,7 @@ def status():
     return subprocess.getoutput("git status")
 
 
-def push_branch(m:str,b:str,url:str) -> str:
+def push_branch(m:str,b:str,**url:str) -> str:
     try:    
         cmd_remote = "git remote add origin {0}".format(url)
         cmd_branch = "git checkout {} ".format(b)
@@ -17,14 +17,14 @@ def push_branch(m:str,b:str,url:str) -> str:
         cmd_push = "git push origin {}".format(b)
         if(b=="master" or b=="main" and m=="initial commit"):
             subprocess.getoutput('git init')
-            subprocess.getoutput("git add .") 
+            subprocess.getoutput("git add .")  
             subprocess.getoutput(cmd_remote)
             print(cmd_remote)
-            subprocess.getoutput(cmd_branch)# I ch
+            subprocess.getoutput(cmd_branch)
             print(cmd_message)
             subprocess.getoutput(cmd_message)
             result = subprocess.getoutput(cmd_push)
-            return  result #initially you want to push
+            return  result
         else:
             subprocess.getoutput(cmd_branch)     
             subprocess.getoutput("git add -u")
